//Software base para OPS012
//Controlador ESP32

//Biblioteca para temperatura/carga
#include <HX711_ADC.h>

//Definição dos pinos do controlador
//Saidas digiais
#define pin_Y1 13
#define pin_Y2 12
#define pin_Y3 27
#define pin_Y4 26
#define pin_Y5 25
#define pin_Y6 33

//Entradas digitais
#define pin_X1 15
#define pin_X2 14
#define pin_X3 39
#define pin_X4 36

//Entradas analógicas
#define AV3 35
#define AV4 34

//Saidas analogicas
#define AO1 32
#define AO2 23

//Entradas de temperatura - a placa conta com duas entradas de temperatura
const int Temp_DOUT_PIN1 = 18;
const int Temp_SCK_PIN1 = 5;

const int Temp_DOUT_PIN2 = 19;
const int Temp_SCK_PIN2 = 4;

//variaveis para o teste de temperatura
unsigned long tempTime1 = 0; //tempo para realização de cada leitura para ter uma estabilidade maior
long Raw_temp1 = 0; //armazena valores analógicos de 24bits (-8388607 a 8388607)
double temp1 = 0; //armazenas os valoes em graus, já calibrados

unsigned long tempTime2 = 0;
long Raw_temp2 = 0;
double temp2 = 0;

//chamada da biblioteca identificando os pinos, pinagens do HX711(DOUT e SCK)
                 //Prefixo DOUT    Prefixo SCK
HX711_ADC Sensor1(Temp_DOUT_PIN1, Temp_SCK_PIN1);
HX711_ADC Sensor2(Temp_DOUT_PIN2, Temp_SCK_PIN2);

void setup() {
  Serial.begin(115200);//USB
  Serial1.begin(115200, SERIAL_8N1, 22, 21); // (TTL)
  Serial2.begin(115200); //(485)

  //Inicializa hardware
  pinMode(pin_X1, INPUT);
  pinMode(pin_X2, INPUT);
  pinMode(pin_X3, INPUT);
  //A leitura do X4 é feita como analógica

  pinMode(pin_Y1, OUTPUT);
  pinMode(pin_Y2, OUTPUT);
  pinMode(pin_Y3, OUTPUT);
  pinMode(pin_Y4, OUTPUT);
  pinMode(pin_Y5, OUTPUT);
  pinMode(pin_Y6, OUTPUT);

  //incio da biblioteca HX711
  //a biblioteca funciona tanto para a leitura de celula de carga e de temperatura
  //para a leitura de temperatura alguns parametros tem que ser ajustados dessa forma
  Sensor1.begin(); //incia a biblioteca
  
  //inicia a leitura depois do tempo definido em ms (para o sensor gerar uma leitura sem muitas ocilações inicias)
  //e false no caso da leitura de temperatura, caso queira fazer uma leitura de celula de carga trocar para true
  Sensor1.start(2000, false);
  
  //coloca o fator de calibração em 1, para ter a certeza que não havera mudanças nos valores medidos, caso esteja 
  //fazendo a leitura de celula de carga coloque o valor de calibração que satisfazer a leitura  
  Sensor1.setCalFactor(1); 

  Sensor2.begin();
  Sensor2.start(2000, false);
  Sensor2.setCalFactor(1);

}

void loop() {
  //primeiro dizemos de quanto em quanto tempo faremos a leitura em ms
  if (millis() >= (tempTime1 + 1000)) {// nesse caso a leitura está sendo feita a cada 1000 ms 
    if (Sensor1.update()) { //aguarda o conversor realizar a leitura da entrada analogica
      //realiza a leitura e registra um valor analogico  
      Raw_temp1 = Sensor1.getData();
      Serial.print("Valor Raw da entrada 1: ");
      Serial.println(Raw_temp1); //Utilizar esse valor para calibração
    }
    tempTime1 = millis(); //reinicia a contagem do tempo para a proxima leitura 
  }

  if (millis() >= (tempTime2 + 1000)) {
    if (Sensor2.update()) {
      Raw_temp2 = Sensor2.getData();
    }
    tempTime2 = millis();
  }

  //É necessário calibrar a leitura para cada tipo de sensor e para obter valores em graus 
  //Valor_Calibrado = map(Valor_Entrada, Entrada_min, Entrada_Max, Valor_Min, Valor_Max);
  //Nesse exemplo os valores de calibração foram:
  //Valor_Min = 0 graus obteve uma Entrada_min = 8386500
  //Valor_Max = 25 graus obteve uma Entrada_Max = 8387580
  //o valor está com duas casa decimais 
  temp1 = map(Raw_temp1, 8386500, 8387580, 0, 2500);
  temp2 = map(Raw_temp2, 8386500, 8387580, 0, 2500);

  Serial.print("Temperatura1: "); //imprime um texto
  Serial.print(temp1 / 100);      //de acordo com a calibração a cima imprime o valor da temperatura em graus com duas casas decimais 
  Serial.print("/");
  Serial.println(Raw_temp1);      //imprime o valor de temperatura em um valor analogico

  Serial.print("Temperatura2: ");
  Serial.print(temp2 / 100);
  Serial.print("/");
  Serial.println(Raw_temp2);
  Serial.println("***********************************************************");

}
